<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sq">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Spastroji Krejt</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation>Palose</translation>
    </message>
    <message>
        <source>More</source>
        <translation>Më tepër</translation>
    </message>
</context>
<context>
    <name>NotifyCenter</name>
    <message>
        <source>No recent notifications</source>
        <translation>S’ka njoftime së fundi</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Qendër Njoftimesh</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Spastroji Krejt</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation>Palose</translation>
    </message>
    <message>
        <source>More</source>
        <translation>Më tepër</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Shfiksoje</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Fiksoje</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Rregullime Njoftimesh</translation>
    </message>
</context>
<context>
    <name>NotifyViewDelegate</name>
    <message>
        <source>Clean All</source>
        <translation>Spastroji Krejt</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Mu tani</translation>
    </message>
</context>
</TS>
